Learn R Programming

fromo (version 0.2.5)

cent2raw: Convert between different types of moments, raw, central, standardized.

Description

Given raw or central or standardized moments, convert to another type.

Usage

cent2raw(input)

Arguments

input

a vector of the count, then the mean, then the 2 through k raw or central moments.

Author

Steven E. Pav [email protected]