Learn R Programming

fromo (version 0.2.5)

centcosums-accessor: Accessor methods.

Description

Access slot data from a centcosums object.

Usage

cosums(x)

# S4 method for centcosums cosums(x)

comoments(x, type = c("central", "raw"), used_df = 0)

# S4 method for centcosums comoments(x, type = c("central", "raw"), used_df = 0)

Arguments

x

a centcosums object.

type

the type of moment to compute.

used_df

the number of used degrees of freedom, only for computing the covariance, and only for the ‘central’ type of comoment.

Author

Steven E. Pav [email protected]