Learn R Programming

fromo (version 0.2.5)

fromo-NEWS: News for package 'fromo':

Description

News for package 'fromo'

Arguments

<a href="https://github.com/shabbychef/fromo"></a> Version 0.2.5 (2026-09-15)

  • now tests for positive restart_period, throw error otherwise.

  • NA restart_period more explicitly means "infinite"

  • remove unused compute_se from t_running_tstat

  • catch size mismatch in running_co* and t_running_co*

  • split out and fix cent_sums man page

  • fix default order in centsums and centcosums

  • fix documentation for t_running comoments

  • adding various size checks.

  • fix computation of comoments

  • NA variance would have been standardized to 1, fixed.

  • fix moments output size for edge cases of few moments.

  • as.centsums default value of normalize_wts changed to true.

  • (t_)running_cent_moments w/ max_order_only true, max_order=2 previously returned stdev; now returns variance.

<a href="https://github.com/shabbychef/fromo"></a> Version 0.2.4 (2024-11-29)

  • adding running correlation, covariance, regression coefficients.

  • adding t-running correlation, covariance, regression coefficients.

<a href="https://github.com/shabbychef/fromo"></a> Version 0.2.3 (2024-11-07)

  • adding flag and checking for negative even moments due to roundoff.

  • fixing divide by zero which would corrupt results when input was constant.

<a href="https://github.com/shabbychef/fromo"></a> Version 0.2.2 (2024-11-03)

  • fix t_running_sum and others to act as documented when variable_win is flagged.

<a href="https://github.com/shabbychef/fromo"></a> Version 0.2.1 (2019-01-29)

  • fix memory leak for case where the mean only need be computed via a Welford object.

<a href="https://github.com/shabbychef/fromo"></a> Version 0.2.0 (2019-01-12)

  • add std_cumulants

  • add running_sum, running_mean.

  • Kahan compensated summation for these.

  • Welford object under the hood.

  • add weighted moments computation.

  • add time-based running window computations.

  • some speedups for obviously fast cases: no checking of NA, etc.

  • move github figures to location CRAN understands.

<a href="https://github.com/shabbychef/fromo"></a> Version 0.1.3 (2016-04-04)

  • submit to CRAN

<a href="https://github.com/shabbychef/fromo"></a> Initial Version 0.1.0 (2016-03-25)

  • start work