Access slot data from a centcosums object.
cosums(x)# S4 method for centcosums
cosums(x)
comoments(x, type = c("central", "raw"), used_df = 0)
# S4 method for centcosums
comoments(x, type = c("central", "raw"), used_df = 0)
a centcosums object.
the type of moment to compute.
the number of used degrees of freedom, only for computing the covariance, and only for the ‘central’ type of comoment.
Steven E. Pav [email protected]